multidim.fast\_algorithms
=========================

.. automodule:: multidim.fast_algorithms

   
   
   .. rubric:: Functions

   .. autosummary::
   
      check_heights
      covertree_adopt_or_liberate
      covertree_befriend321
      covertree_exchange_teens
      distance_cache_None
      distance_cache_dict
      distance_cache_dok
      distance_cache_numpy
      edges_from_dists
      entropy
      gaussian
      gaussian_fit
      gaussian_fit_wt
      is_partition_bool
      is_partition_list
      label_means
      label_weights
   
   

   
   
   

   
   
   